#!/usr/bin/env python

"""
usage: mkflat4.py  osslist  prefix_of_outflatname(e.g,. 'flat')
"""

import sys
from pyraf import iraf

iraf.stdimage = 'imt4096'
ccd_arrange = 'ccd_arrange.lis'


# ---------------------------------------------
def mklist(osslist):
# ---------------------------------------------
    fitslist_all=[ [],[],[],[],[],[],[],[],[],[] ]

    for fits in open(osslist):
        fits=fits.strip()
        detid=iraf.hselect(fits, 'det-id', 'yes', Stdout=1) # return is a list
        #print detid
        detid=int(detid[0])

        fitslist_all[detid].append(fits)

    print 'resultant fitslist_all: ', fitslist_all

    return fitslist_all
    

# ---------------------------------------------
def norm(fitslist_per_detid): # <-- definition of function
# ---------------------------------------------
    #for infits in open(fitslist_per_detid):
    for infits in fitslist_per_detid:

        print infits
        outfits='nrm_'+infits

        # -- measure median of the sky background counts
        med=iraf.imstat(infits, fields='midpt', Stdout=1)
        med=float(med[1])
        print 'infits=%s: median=%f' % (infits, med)

        # -- divide the input image by the median  
        print 'executing %s / %f = %s' % (infits, med, outfits)
        iraf.imarith(infits, '/', med, outfits)

    print 'norm() - done.'

# ---------------------------------------------
def comb(fitslist_per_detid, outflat):
# ---------------------------------------------

    # -- 1. creating a list of nrm frames

    fitslist = []
    for fits in fitslist_per_detid:
        nrmfits='nrm_' + fits.strip()
        fitslist.append(nrmfits)      # add this nrm fits name to the fitslist
    fitslist = ','.join(fitslist)     # imcombine only accepts 'file1,file2,file3,...'

    print 'input fitslist: ', fitslist

    # -- 2. stack the fits files to a flat 

    print 'stacking - ', fitslist, ' into ', outflat

    iraf.imcombine(fitslist, combine='median', output=outflat)

    print 'comb() - done.'

# ---------------------------------------------
def ds9(fits,detid):
# ---------------------------------------------                 

    detid_frame = {} # creating a new empty dictionary
    for line in open(ccd_arrange):
        line=line.strip().split()
        if line[0].startswith('#') == False:
            frame=int(line[0]) # converting to integer
            detid_ds9=int(line[1])

            if(detid==detid_ds9):
                iraf.display(fits, frame, fill=1, zscale=1, zrange=0, z1=None, z2=None)
                print 'displaying - %s in frame %d' % (fits, frame)
                
                return 

# ---------------------------------------------
def main():
# ---------------------------------------------
    if len(sys.argv) != 3:
        print __doc__
        sys.exit(0)

    osslist=sys.argv[1]
    prefix_outflat=sys.argv[2]


    fitslist_all=mklist(osslist) # a list of lists

    # inputing fits list for each detid

    detid=0
    for fitslist_per_detid in fitslist_all:
        outflat=prefix_outflat+str(detid)+'.fits'
        norm(fitslist_per_detid)
        comb(fitslist_per_detid, outflat)

        ds9(outflat, detid)
        detid += 1

# --- this is the main part ---
if __name__ == "__main__":
    main()
