#!/usr/bin/env python

"""
usage: ffield3.py  infits.list  flat.fits
"""

# flatfielding with multiple CPU cores

import sys
import multiprocessing as mp # <-- module to realize multiprocessing
from pyraf import iraf 

# ---------------------------------------
def ffield_multiprocess(osslist, flat):
# ---------------------------------------
    osslist=sys.argv[1]

    infitslist=[]
    flatlist=[]
    for line in open(osslist):
        infitslist.append(line.rstrip())
        flatlist.append(flat)

    nfits=len(infitslist) # number of input oss files

    infits_flat_list=zip(infitslist, flatlist) # pair of infits & flat
    print infits_flat_list
    
    # number of python processes to be forked at a time
    number_of_cores=mp.cpu_count()
    n_processes= 2
    print 'number_of_cores: ', number_of_cores
    print 'maximal number of processes: ', n_processes

    # creating Pool for processes, by specifying num of processes
    p=mp.Pool(n_processes)

    # invoking the pooled processes  
    # note: if function has multiple arguments, the arguments 
    # has to be given in a tuple format

    print 'Invoking multiple processes, each of which runs ffield() ...'
    p.map(ffield, infits_flat_list)
    print 'ffield_multiprocess() - done.'

# ---------------------------------------
def ffield(infits_flat): 
# ---------------------------------------

    (infits, flat) = infits_flat # extract infits & flat from them the tuple infits_flat
    outfits='flt_'+infits

    # -- divide the input image by flat image

    print 'executing %s / %s = %s' % (infits, flat, outfits)
    iraf.imarith(infits, '/', flat, outfits) # <-- PyRAF task

    print 'ffield() - done.'


# ---------------------------------------
def main():
# ---------------------------------------
    if len(sys.argv) != 3:
        print __doc__
        sys.exit(0)

    osslist=sys.argv[1]
    flat=sys.argv[2]

    ffield_multiprocess(osslist, flat)
    

# --- this is the main part ---
if __name__ == "__main__":
    main()

