#!/usr/bin/env python

"""
usage: check_ff.py  inputlist 
"""

import sys
import math
import matplotlib.pyplot as plt
from pyraf import iraf

def check_ff(infits): 

    # -- divide the input image by flat image

    region1=infits+'[500:1500, 500:2000]'
    region2=infits+'[500:1500, 2500:4000]'
    print 'checking %s and %s' % (region1, region2)
    ret=iraf.imstat(region1, fields='midpt', Stdout=1)
    skylevel1=float(ret[1])
    ret=iraf.imstat(region2, fields='midpt', Stdout=1)
    skylevel2=float(ret[1])

    delta = 100.0*(skylevel2-skylevel1)/skylevel1
    
    print 'check_ff(): ', delta, ' - done.'

    return skylevel1, skylevel2, delta


#---------------------------------------------
def plot_result(xx, yy):
#---------------------------------------------

    plt.ioff()

    plt.plot(yy, 'o', label='Flatfielded Data', markersize=10)

    plt.xticks(range(len(xx)), xx) # pairing 0,1,2.. <==> xx[0],xx[1],..
#    plt.xticks(range(len(xx)), xx, rotation=0)

#    plt.plot(x, a+0.0*x, 'r', label='Fitted line')
    plt.ylim(-10.0,10.0)
    plt.legend()
    plt.grid()
    plt.xlabel('FITS name')
    plt.ylabel('delta (skylevel2-skylevel1)/skylevel1 (\%)')
    plt.draw()
###    plt.savefig(outfig, format='png', transparent=False)

    plt.show()


def main():
    if len(sys.argv) != 2:
        print __doc__
        sys.exit(0)

    inputlist=sys.argv[1]

    xx=[] # for plot
    yy=[] # for plot
    
    for infits in open(inputlist):
        infits=infits.strip()

        skylevel1,skylevel2,delta = check_ff(infits)

        frameid=infits.replace('.fits','')
        frameid=frameid.replace('flt_oss_','')

        xx.append(frameid)
        yy.append(delta)

    plot_result(xx,yy) 
        
    

# --- this is the main part ---
if __name__ == "__main__":
    main()
