#!/usr/bin/env python

"""
usage: check_ff2.py  inputlist 
"""

import sys
import math
import matplotlib.pyplot as plt
from pyraf import iraf

#---------------------------------------------
def check_ff2(infits, x_meshsize, y_meshsize): 
#---------------------------------------------
    # -- divide the input image by flat image

    ret=iraf.hselect(infits, 'naxis1,naxis2', 'yes', Stdout=1)[0].split()
    xmax=int(ret[0])
    ymax=int(ret[1])
    print 'xmax,ymax:', xmax, ymax

    skylevel = []

    x1=1
    x2=x1+x_meshsize
    y1=1
    y2=y1+y_meshsize
    while y2<ymax:
        x1=1
        x2=x1+x_meshsize
        while x2<xmax:
            region=infits+'['+str(x1)+':'+str(x2)+','+str(y1)+':'+str(y2)+']'
            print 'checking: ', region

            ret=iraf.imstat(region, fields='midpt', Stdout=1)
            skylevel.append(float(ret[1]))
            x1 += x_meshsize
            x2 += x_meshsize

        y1 += y_meshsize
        y2 += y_meshsize

    print 'n sampling: ', len(skylevel)

    # the below part is just for practice. NumPy function is much faster. 
    # Can you rewrite this?
    mean,stddev=calc_stddev(skylevel) 
    delta_stddev = 100.0*(stddev/mean)

    skylevel.sort()
    delta_pp = 100.0*(skylevel[-1]-skylevel[0])/skylevel[0]
    
    print 'check_ff2(): ', mean, delta_stddev, delta_pp, ' - done.'

    return mean, delta_stddev, delta_pp

#---------------------------------------------
def calc_stddev(val_list): 
#---------------------------------------------
    # this function is to be replaced with Numpy function
    x=0
    x2=0
    i=0
    for val in val_list:
        x += val
        i += 1
    mean=x/i    
    for val in val_list:
        x2 += (val-mean)*(val-mean)

    if i>1:
        stddev=math.sqrt(x2/(i-1))  # using sqrt() function in math module
    else:
        stddev=0.0;

    return mean,stddev

#---------------------------------------------
def check_ff(infits): 
#---------------------------------------------
    # -- divide the input image by flat image

    region1=infits+'[500:1500, 500:2000]'
    region2=infits+'[500:1500, 2500:4000]'
    print 'checking %s and %s' % (region1, region2)
    ret=iraf.imstat(region1, fields='midpt', Stdout=1)
    skylevel1=float(ret[1])
    ret=iraf.imstat(region2, fields='midpt', Stdout=1)
    skylevel2=float(ret[1])

    delta = 100.0*(skylevel2-skylevel1)/skylevel1
    
    print 'check_ff(): ', delta, ' - done.'

    return skylevel1, skylevel2, delta


#---------------------------------------------
def plot_result(xx, yy):
#---------------------------------------------

    plt.ioff()

    plt.plot(yy, 'o', label='Flatfielded Data', markersize=10)

    plt.xticks(range(len(xx)), xx) # pairing 0,1,2.. <==> xx[0],xx[1],..
#    plt.xticks(range(len(xx)), xx, rotation=0)

#    plt.plot(x, a+0.0*x, 'r', label='Fitted line')
    plt.ylim(-10.0,10.0)
    plt.legend()
    plt.grid()
    plt.xlabel('FITS name')
    plt.ylabel('delta (skylevel2-skylevel1)/skylevel1 (\%)')
###    plt.draw()
###    plt.savefig(outfig, format='png', transparent=False)

    plt.show()

#---------------------------------------------
def plot_result2(xx, yy1, yy2):
#---------------------------------------------

    plt.ioff()

    plt.plot(yy1, 'o', label='Peak-to-peak difference / Sky', markersize=10)
    plt.plot(yy2, 'x', label='Standard Deviation / Sky', markersize=10)

    plt.xticks(range(len(xx)), xx) # pairing 0,1,2.. <==> xx[0],xx[1],..
#    plt.xticks(range(len(xx)), xx, rotation=0)

    plt.ylim(-10.0,10.0)
    plt.legend()
    plt.grid()
    plt.xlabel('FITS name')
    plt.ylabel('delta sky-pp or sky-stddev/skylevel (\%)')
###    plt.draw()
###    plt.savefig(outfig, format='png', transparent=False)

    plt.show()

#---------------------------------------------
def main():
#---------------------------------------------
    if len(sys.argv) != 2:
        print __doc__
        sys.exit(0)

    inputlist=sys.argv[1]

    xx=[] # for plot
    yy1=[] # for plot
    yy2=[] #

    for infits in open(inputlist):
        infits=infits.strip()

        mean,delta_stddev,delta_pp = check_ff2(infits, x_meshsize=2000, y_meshsize=2000)

        frameid=infits.replace('.fits','')
        frameid=frameid.replace('flt_oss_','')

        xx.append(frameid)
        yy1.append(delta_pp)
        yy2.append(delta_stddev)

    print yy1, yy2
    plot_result2(xx,yy1,yy2) 
        
    

# --- this is the main part ---
if __name__ == "__main__":
    main()
